@@ -1093,7 +1093,10 @@ TEST_CASE("1. unicode to upper", "[detail]")
         table_map[0xa7c8] = 0xa7c7;
         table_map[0xa7ca] = 0xa7c9;
         table_map[0xa7cd] = 0xa7cc;
+        table_map[0xa7cf] = 0xa7ce;
         table_map[0xa7d1] = 0xa7d0;
+        table_map[0xa7d3] = 0xa7d2;
+        table_map[0xa7d5] = 0xa7d4;
         table_map[0xa7d7] = 0xa7d6;
         table_map[0xa7d9] = 0xa7d8;
         table_map[0xa7db] = 0xa7da;
@@ -1453,6 +1456,31 @@ TEST_CASE("1. unicode to upper", "[detail]")
         table_map[0x16e7d] = 0x16e5d;
         table_map[0x16e7e] = 0x16e5e;
         table_map[0x16e7f] = 0x16e5f;
+        table_map[0x16ebb] = 0x16ea0;
+        table_map[0x16ebc] = 0x16ea1;
+        table_map[0x16ebd] = 0x16ea2;
+        table_map[0x16ebe] = 0x16ea3;
+        table_map[0x16ebf] = 0x16ea4;
+        table_map[0x16ec0] = 0x16ea5;
+        table_map[0x16ec1] = 0x16ea6;
+        table_map[0x16ec2] = 0x16ea7;
+        table_map[0x16ec3] = 0x16ea8;
+        table_map[0x16ec4] = 0x16ea9;
+        table_map[0x16ec5] = 0x16eaa;
+        table_map[0x16ec6] = 0x16eab;
+        table_map[0x16ec7] = 0x16eac;
+        table_map[0x16ec8] = 0x16ead;
+        table_map[0x16ec9] = 0x16eae;
+        table_map[0x16eca] = 0x16eaf;
+        table_map[0x16ecb] = 0x16eb0;
+        table_map[0x16ecc] = 0x16eb1;
+        table_map[0x16ecd] = 0x16eb2;
+        table_map[0x16ece] = 0x16eb3;
+        table_map[0x16ecf] = 0x16eb4;
+        table_map[0x16ed0] = 0x16eb5;
+        table_map[0x16ed1] = 0x16eb6;
+        table_map[0x16ed2] = 0x16eb7;
+        table_map[0x16ed3] = 0x16eb8;
         table_map[0x1e922] = 0x1e900;
         table_map[0x1e923] = 0x1e901;
         table_map[0x1e924] = 0x1e902;
